@@ -25,22 +25,18 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <libempathy/empathy-debug.h>
-
+#include <libempathy/empathy-utils.h>
 #include "empathy-ui-utils.h"
-#include "empathy-main-window.h"
 #include "empathy-theme-boxes.h"
 
-#define DEBUG_DOMAIN "FancyTheme"
+#define DEBUG_FLAG EMPATHY_DEBUG_OTHER
+#include <libempathy/empathy-debug.h>
 
 #define MARGIN 4
 #define HEADER_PADDING 2
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_THEME_BOXES, EmpathyThemeBoxesPriv))
-
-typedef struct _EmpathyThemeBoxesPriv EmpathyThemeBoxesPriv;
-
-struct _EmpathyThemeBoxesPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyThemeBoxes)
+typedef struct {
 	gchar *header_foreground;
 	gchar *header_background;
 	gchar *header_line_background;
@@ -52,7 +48,7 @@ struct _EmpathyThemeBoxesPriv {
 	gchar *event_foreground;
 	gchar *invite_foreground;
 	gchar *link_foreground;
-};
+} EmpathyThemeBoxesPriv;
 
 static void     theme_boxes_finalize          (GObject            *object);
 static void     theme_boxes_get_property      (GObject            *object,
@@ -217,9 +213,10 @@ empathy_theme_boxes_class_init (EmpathyThemeBoxesClass *class)
 static void
 empathy_theme_boxes_init (EmpathyThemeBoxes *theme)
 {
-	EmpathyThemeBoxesPriv *priv;
+	EmpathyThemeBoxesPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (theme,
+		EMPATHY_TYPE_THEME_BOXES, EmpathyThemeBoxesPriv);
 
-	priv = GET_PRIV (theme);
+	theme->priv = priv;
 }
 
 static void
@@ -528,10 +525,10 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 {
 	EmpathyThemeBoxesPriv *priv;
 	EmpathyContact        *contact;
+	EmpathyContact        *last_contact;
 	GdkPixbuf            *avatar = NULL;
 	GtkTextBuffer        *buffer;
 	const gchar          *name;
-	gboolean              header;
 	GtkTextIter           iter;
 	GtkWidget            *label1, *label2;
 	GtkTextChildAnchor   *anchor;
@@ -542,42 +539,20 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 	GtkTextIter           start;
 	GdkColor              color;
 	gboolean              parse_success;
-	gboolean              from_self;
 
 	priv = GET_PRIV (theme);
 
 	contact = empathy_message_get_sender (msg);
-	from_self = empathy_contact_is_user (contact);
+	name = empathy_contact_get_name (contact);
+	last_contact = empathy_chat_view_get_last_contact (view);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
-	empathy_debug (DEBUG_DOMAIN, "Maybe add fancy header");
-
-	name = empathy_contact_get_name (contact);
-
-	header = FALSE;
+	DEBUG ("Maybe add fancy header");
 
 	/* Only insert a header if the previously inserted block is not the same
 	 * as this one. This catches all the different cases:
 	 */
-	if (empathy_chat_view_get_last_block_type (view) != EMPATHY_CHAT_VIEW_BLOCK_SELF &&
-	    empathy_chat_view_get_last_block_type (view) != EMPATHY_CHAT_VIEW_BLOCK_OTHER) {
-		header = TRUE;
-	}
-	else if (from_self &&
-		 empathy_chat_view_get_last_block_type (view) == EMPATHY_CHAT_VIEW_BLOCK_OTHER) {
-		header = TRUE;
-	}
-	else if (!from_self && 
-		 empathy_chat_view_get_last_block_type (view) == EMPATHY_CHAT_VIEW_BLOCK_SELF) {
-		header = TRUE;
-	}
-	else if (!from_self &&
-		 (!empathy_chat_view_get_last_contact (view) ||
-		  !empathy_contact_equal (contact, empathy_chat_view_get_last_contact (view)))) {
-		header = TRUE;
-	}
-
-	if (!header) {
+	if (last_contact && empathy_contact_equal (last_contact, contact)) {
 		return;
 	}
 
@@ -597,22 +572,23 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 	box = gtk_hbox_new (FALSE, 0);
 
 
-	avatar = empathy_chat_view_get_avatar_pixbuf_with_cache (contact);
-	if (avatar && empathy_theme_get_show_avatars (theme)) {
-		GtkWidget *image;
+	if (empathy_theme_get_show_avatars (theme)) {
+		avatar = empathy_chat_view_get_avatar_pixbuf_with_cache (contact);
+		if (avatar) {
+			GtkWidget *image;
 
-		image = gtk_image_new_from_pixbuf (avatar);
-
-		gtk_box_pack_start (GTK_BOX (box), image,
-				    FALSE, TRUE, 2);
+			image = gtk_image_new_from_pixbuf (avatar);
 
+			gtk_box_pack_start (GTK_BOX (box), image,
+					    FALSE, TRUE, 2);
+		}
 	}
 
 	g_signal_connect_object (view, "size-allocate",
 				 G_CALLBACK (table_size_allocate_cb),
 				 box, 0);
 
-	str = g_strdup_printf ("<b>%s</b>", name);
+	str = g_markup_printf_escaped ("<b>%s</b>", name);
 
 	label1 = g_object_new (GTK_TYPE_LABEL,
 			       "label", str,
@@ -695,7 +671,7 @@ theme_boxes_append_message (EmpathyTheme        *theme,
 
 	sender = empathy_message_get_sender (message);
 
-	if (empathy_message_get_type (message) == EMPATHY_MESSAGE_TYPE_ACTION) {
+	if (empathy_message_get_tptype (message) == TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION) {
 		gchar *body;
 
 		body = g_strdup_printf (" * %s %s", 
@@ -708,14 +684,6 @@ theme_boxes_append_message (EmpathyTheme        *theme,
 					   empathy_message_get_body (message),
 					   "fancy-body", "fancy-link");
 	}
-	
-	if (empathy_contact_is_user (sender)) {
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_SELF);
-		empathy_chat_view_set_last_contact (view, NULL);
-	} else {
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_OTHER);
-		empathy_chat_view_set_last_contact (view, sender);
-	}
 }
 
 static void
@@ -740,8 +708,6 @@ theme_boxes_append_event (EmpathyTheme        *theme,
 						  "fancy-event",
 						  NULL);
 	g_free (msg);
-
-	empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_EVENT);
 }
 
 static void
@@ -804,7 +770,6 @@ theme_boxes_append_timestamp (EmpathyTheme        *theme,
 							  "fancy-time",
 							  NULL);
 
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_TIME);
 		empathy_chat_view_set_last_timestamp (view, timestamp);
 	}
 
